@@ -3,7 +3,7 @@ package Log::Dispatch::Syslog;
 use strict;
 use warnings;
 
-our $VERSION = '2.45';
+our $VERSION = '2.46';
 
 use Log::Dispatch::Output;
 
@@ -31,6 +31,8 @@ sub new {
 
 my ($Ident) = $0 =~ /(.+)/;
 
+my $thread_lock;
+
 sub _init {
     my $self = shift;
 
@@ -63,6 +65,7 @@ sub _init {
     if ( $self->{lock} ) {
         require threads;
         require threads::shared;
+        threads::shared::share( \$thread_lock );
     }
 
     $self->{priorities} = [
@@ -77,8 +80,6 @@ sub _init {
     ];
 }
 
-my $thread_lock : shared = 0;
-
 sub log_message {
     my $self = shift;
     my %p    = @_;
@@ -122,7 +123,7 @@ Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 VERSION
 
-version 2.45
+version 2.46
 
 =head1 SYNOPSIS
 
